import setuptools

setuptools.setup(
    name='pogt',
    version='1.0.1',
    author='cdy',
    author_email='xxx201277@yeah.net',
    description='post/get',
    long_description_content_type="""text/markdown""",
    url='https://sb.sb',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ]
)